# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2Constant import Gs2Constant
from gs2_core_client.AbstractGs2Client import AbstractGs2Client
from aws_sdk_for_serverless.common import url_encoder


class Gs2GoldClient(AbstractGs2Client):

    ENDPOINT = "gold"

    def __init__(self, credential, region):
        """
        コンストラクタ
        :param credential: 認証情報
        :type credential: IGs2Credential
        :param region: GS2リージョン
        :type region: str
        """
        super(Gs2GoldClient, self).__init__(credential, region)

    def get_current_gold_master(self, request):
        """
        公開されているゴールドマスタを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.GetCurrentGoldMasterRequest.GetCurrentGoldMasterRequest
        :return: 結果
        :rtype: gs2_gold_client.control.GetCurrentGoldMasterResult.GetCurrentGoldMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.GetCurrentGoldMasterRequest import GetCurrentGoldMasterRequest

        from gs2_gold_client.control.GetCurrentGoldMasterResult import GetCurrentGoldMasterResult
        return GetCurrentGoldMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/master",
            service=self.ENDPOINT,
            component=GetCurrentGoldMasterRequest.Constant.MODULE,
            target_function=GetCurrentGoldMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def update_current_gold_master(self, request):
        """
        公開するゴールドマスタを更新します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.UpdateCurrentGoldMasterRequest.UpdateCurrentGoldMasterRequest
        :return: 結果
        :rtype: gs2_gold_client.control.UpdateCurrentGoldMasterResult.UpdateCurrentGoldMasterResult
        """
        body = { 
            "settings": request.get_settings(),
        }

        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.UpdateCurrentGoldMasterRequest import UpdateCurrentGoldMasterRequest
        from gs2_gold_client.control.UpdateCurrentGoldMasterResult import UpdateCurrentGoldMasterResult
        return UpdateCurrentGoldMasterResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/master",
            service=self.ENDPOINT,
            component=UpdateCurrentGoldMasterRequest.Constant.MODULE,
            target_function=UpdateCurrentGoldMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def create_gold_master(self, request):
        """
        ゴールドマスターを新規作成します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.CreateGoldMasterRequest.CreateGoldMasterRequest
        :return: 結果
        :rtype: gs2_gold_client.control.CreateGoldMasterResult.CreateGoldMasterResult
        """
        body = { 
            "name": request.get_name(),
        }

        if request.get_meta() is not None:
            body["meta"] = request.get_meta()
        if request.get_balance_max() is not None:
            body["balanceMax"] = request.get_balance_max()
        if request.get_reset_type() is not None:
            body["resetType"] = request.get_reset_type()
        if request.get_reset_day_of_month() is not None:
            body["resetDayOfMonth"] = request.get_reset_day_of_month()
        if request.get_reset_day_of_week() is not None:
            body["resetDayOfWeek"] = request.get_reset_day_of_week()
        if request.get_reset_hour() is not None:
            body["resetHour"] = request.get_reset_hour()
        if request.get_latest_gain_max() is not None:
            body["latestGainMax"] = request.get_latest_gain_max()
        if request.get_create_wallet_trigger_script() is not None:
            body["createWalletTriggerScript"] = request.get_create_wallet_trigger_script()
        if request.get_create_wallet_done_trigger_script() is not None:
            body["createWalletDoneTriggerScript"] = request.get_create_wallet_done_trigger_script()
        if request.get_deposit_into_wallet_trigger_script() is not None:
            body["depositIntoWalletTriggerScript"] = request.get_deposit_into_wallet_trigger_script()
        if request.get_deposit_into_wallet_done_trigger_script() is not None:
            body["depositIntoWalletDoneTriggerScript"] = request.get_deposit_into_wallet_done_trigger_script()
        if request.get_withdraw_from_wallet_trigger_script() is not None:
            body["withdrawFromWalletTriggerScript"] = request.get_withdraw_from_wallet_trigger_script()
        if request.get_withdraw_from_wallet_done_trigger_script() is not None:
            body["withdrawFromWalletDoneTriggerScript"] = request.get_withdraw_from_wallet_done_trigger_script()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.CreateGoldMasterRequest import CreateGoldMasterRequest
        from gs2_gold_client.control.CreateGoldMasterResult import CreateGoldMasterResult
        return CreateGoldMasterResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/master/gold",
            service=self.ENDPOINT,
            component=CreateGoldMasterRequest.Constant.MODULE,
            target_function=CreateGoldMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def delete_gold_master(self, request):
        """
        ゴールドマスターを削除します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DeleteGoldMasterRequest.DeleteGoldMasterRequest
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DeleteGoldMasterRequest import DeleteGoldMasterRequest
        self._do_delete_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/master/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "",
            service=self.ENDPOINT,
            component=DeleteGoldMasterRequest.Constant.MODULE,
            target_function=DeleteGoldMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        )

    def describe_gold_master(self, request):
        """
        ゴールドマスターの一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DescribeGoldMasterRequest.DescribeGoldMasterRequest
        :return: 結果
        :rtype: gs2_gold_client.control.DescribeGoldMasterResult.DescribeGoldMasterResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DescribeGoldMasterRequest import DescribeGoldMasterRequest

        from gs2_gold_client.control.DescribeGoldMasterResult import DescribeGoldMasterResult
        return DescribeGoldMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/master/gold",
            service=self.ENDPOINT,
            component=DescribeGoldMasterRequest.Constant.MODULE,
            target_function=DescribeGoldMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_gold_master(self, request):
        """
        ゴールドマスターを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.GetGoldMasterRequest.GetGoldMasterRequest
        :return: 結果
        :rtype: gs2_gold_client.control.GetGoldMasterResult.GetGoldMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.GetGoldMasterRequest import GetGoldMasterRequest

        from gs2_gold_client.control.GetGoldMasterResult import GetGoldMasterResult
        return GetGoldMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/master/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "",
            service=self.ENDPOINT,
            component=GetGoldMasterRequest.Constant.MODULE,
            target_function=GetGoldMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def update_gold_master(self, request):
        """
        ゴールドマスターを更新します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.UpdateGoldMasterRequest.UpdateGoldMasterRequest
        :return: 結果
        :rtype: gs2_gold_client.control.UpdateGoldMasterResult.UpdateGoldMasterResult
        """
        body = { 
        }
        if request.get_meta() is not None:
            body["meta"] = request.get_meta()
        if request.get_balance_max() is not None:
            body["balanceMax"] = request.get_balance_max()
        if request.get_reset_type() is not None:
            body["resetType"] = request.get_reset_type()
        if request.get_reset_day_of_month() is not None:
            body["resetDayOfMonth"] = request.get_reset_day_of_month()
        if request.get_reset_day_of_week() is not None:
            body["resetDayOfWeek"] = request.get_reset_day_of_week()
        if request.get_reset_hour() is not None:
            body["resetHour"] = request.get_reset_hour()
        if request.get_latest_gain_max() is not None:
            body["latestGainMax"] = request.get_latest_gain_max()
        if request.get_create_wallet_trigger_script() is not None:
            body["createWalletTriggerScript"] = request.get_create_wallet_trigger_script()
        if request.get_create_wallet_done_trigger_script() is not None:
            body["createWalletDoneTriggerScript"] = request.get_create_wallet_done_trigger_script()
        if request.get_deposit_into_wallet_trigger_script() is not None:
            body["depositIntoWalletTriggerScript"] = request.get_deposit_into_wallet_trigger_script()
        if request.get_deposit_into_wallet_done_trigger_script() is not None:
            body["depositIntoWalletDoneTriggerScript"] = request.get_deposit_into_wallet_done_trigger_script()
        if request.get_withdraw_from_wallet_trigger_script() is not None:
            body["withdrawFromWalletTriggerScript"] = request.get_withdraw_from_wallet_trigger_script()
        if request.get_withdraw_from_wallet_done_trigger_script() is not None:
            body["withdrawFromWalletDoneTriggerScript"] = request.get_withdraw_from_wallet_done_trigger_script()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.UpdateGoldMasterRequest import UpdateGoldMasterRequest
        from gs2_gold_client.control.UpdateGoldMasterResult import UpdateGoldMasterResult
        return UpdateGoldMasterResult(self._do_put_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/master/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "",
            service=self.ENDPOINT,
            component=UpdateGoldMasterRequest.Constant.MODULE,
            target_function=UpdateGoldMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def create_gold_pool(self, request):
        """
        ゴールドプールを新規作成します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.CreateGoldPoolRequest.CreateGoldPoolRequest
        :return: 結果
        :rtype: gs2_gold_client.control.CreateGoldPoolResult.CreateGoldPoolResult
        """
        body = { 
            "name": request.get_name(),
            "serviceClass": request.get_service_class(),
        }

        if request.get_description() is not None:
            body["description"] = request.get_description()
        if request.get_create_wallet_trigger_script() is not None:
            body["createWalletTriggerScript"] = request.get_create_wallet_trigger_script()
        if request.get_create_wallet_done_trigger_script() is not None:
            body["createWalletDoneTriggerScript"] = request.get_create_wallet_done_trigger_script()
        if request.get_deposit_into_wallet_trigger_script() is not None:
            body["depositIntoWalletTriggerScript"] = request.get_deposit_into_wallet_trigger_script()
        if request.get_deposit_into_wallet_done_trigger_script() is not None:
            body["depositIntoWalletDoneTriggerScript"] = request.get_deposit_into_wallet_done_trigger_script()
        if request.get_withdraw_from_wallet_trigger_script() is not None:
            body["withdrawFromWalletTriggerScript"] = request.get_withdraw_from_wallet_trigger_script()
        if request.get_withdraw_from_wallet_done_trigger_script() is not None:
            body["withdrawFromWalletDoneTriggerScript"] = request.get_withdraw_from_wallet_done_trigger_script()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.CreateGoldPoolRequest import CreateGoldPoolRequest
        from gs2_gold_client.control.CreateGoldPoolResult import CreateGoldPoolResult
        return CreateGoldPoolResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool",
            service=self.ENDPOINT,
            component=CreateGoldPoolRequest.Constant.MODULE,
            target_function=CreateGoldPoolRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def delete_gold_pool(self, request):
        """
        ゴールドプールを削除します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DeleteGoldPoolRequest.DeleteGoldPoolRequest
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DeleteGoldPoolRequest import DeleteGoldPoolRequest
        self._do_delete_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "",
            service=self.ENDPOINT,
            component=DeleteGoldPoolRequest.Constant.MODULE,
            target_function=DeleteGoldPoolRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        )

    def describe_gold_pool(self, request):
        """
        ゴールドプールの一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DescribeGoldPoolRequest.DescribeGoldPoolRequest
        :return: 結果
        :rtype: gs2_gold_client.control.DescribeGoldPoolResult.DescribeGoldPoolResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DescribeGoldPoolRequest import DescribeGoldPoolRequest

        from gs2_gold_client.control.DescribeGoldPoolResult import DescribeGoldPoolResult
        return DescribeGoldPoolResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool",
            service=self.ENDPOINT,
            component=DescribeGoldPoolRequest.Constant.MODULE,
            target_function=DescribeGoldPoolRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def describe_service_class(self, request):
        """
        サービスクラスの一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DescribeServiceClassRequest.DescribeServiceClassRequest
        :return: 結果
        :rtype: gs2_gold_client.control.DescribeServiceClassResult.DescribeServiceClassResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DescribeServiceClassRequest import DescribeServiceClassRequest

        from gs2_gold_client.control.DescribeServiceClassResult import DescribeServiceClassResult
        return DescribeServiceClassResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/serviceClass",
            service=self.ENDPOINT,
            component=DescribeServiceClassRequest.Constant.MODULE,
            target_function=DescribeServiceClassRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_gold_pool(self, request):
        """
        ゴールドプールを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.GetGoldPoolRequest.GetGoldPoolRequest
        :return: 結果
        :rtype: gs2_gold_client.control.GetGoldPoolResult.GetGoldPoolResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.GetGoldPoolRequest import GetGoldPoolRequest

        from gs2_gold_client.control.GetGoldPoolResult import GetGoldPoolResult
        return GetGoldPoolResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "",
            service=self.ENDPOINT,
            component=GetGoldPoolRequest.Constant.MODULE,
            target_function=GetGoldPoolRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_gold_pool_status(self, request):
        """
        ゴールドプールの状態を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.GetGoldPoolStatusRequest.GetGoldPoolStatusRequest
        :return: 結果
        :rtype: gs2_gold_client.control.GetGoldPoolStatusResult.GetGoldPoolStatusResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.GetGoldPoolStatusRequest import GetGoldPoolStatusRequest

        from gs2_gold_client.control.GetGoldPoolStatusResult import GetGoldPoolStatusResult
        return GetGoldPoolStatusResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/status",
            service=self.ENDPOINT,
            component=GetGoldPoolStatusRequest.Constant.MODULE,
            target_function=GetGoldPoolStatusRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def update_gold_pool(self, request):
        """
        ゴールドプールを更新します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.UpdateGoldPoolRequest.UpdateGoldPoolRequest
        :return: 結果
        :rtype: gs2_gold_client.control.UpdateGoldPoolResult.UpdateGoldPoolResult
        """
        body = { 
            "serviceClass": request.get_service_class(),
        }
        if request.get_description() is not None:
            body["description"] = request.get_description()
        if request.get_create_wallet_trigger_script() is not None:
            body["createWalletTriggerScript"] = request.get_create_wallet_trigger_script()
        if request.get_create_wallet_done_trigger_script() is not None:
            body["createWalletDoneTriggerScript"] = request.get_create_wallet_done_trigger_script()
        if request.get_deposit_into_wallet_trigger_script() is not None:
            body["depositIntoWalletTriggerScript"] = request.get_deposit_into_wallet_trigger_script()
        if request.get_deposit_into_wallet_done_trigger_script() is not None:
            body["depositIntoWalletDoneTriggerScript"] = request.get_deposit_into_wallet_done_trigger_script()
        if request.get_withdraw_from_wallet_trigger_script() is not None:
            body["withdrawFromWalletTriggerScript"] = request.get_withdraw_from_wallet_trigger_script()
        if request.get_withdraw_from_wallet_done_trigger_script() is not None:
            body["withdrawFromWalletDoneTriggerScript"] = request.get_withdraw_from_wallet_done_trigger_script()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.UpdateGoldPoolRequest import UpdateGoldPoolRequest
        from gs2_gold_client.control.UpdateGoldPoolResult import UpdateGoldPoolResult
        return UpdateGoldPoolResult(self._do_put_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "",
            service=self.ENDPOINT,
            component=UpdateGoldPoolRequest.Constant.MODULE,
            target_function=UpdateGoldPoolRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def export_master(self, request):
        """
        ゴールドマスターデータをエクスポートする<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.ExportMasterRequest.ExportMasterRequest
        :return: 結果
        :rtype: gs2_gold_client.control.ExportMasterResult.ExportMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.ExportMasterRequest import ExportMasterRequest

        from gs2_gold_client.control.ExportMasterResult import ExportMasterResult
        return ExportMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/master",
            service=self.ENDPOINT,
            component=ExportMasterRequest.Constant.MODULE,
            target_function=ExportMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_wallet_settings(self, request):
        """
        ウォレットの設定を取得します<br>
        <br>
        - 消費クオータ: 2<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.GetWalletSettingsRequest.GetWalletSettingsRequest
        :return: 結果
        :rtype: gs2_gold_client.control.GetWalletSettingsResult.GetWalletSettingsResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.GetWalletSettingsRequest import GetWalletSettingsRequest

        from gs2_gold_client.control.GetWalletSettingsResult import GetWalletSettingsResult
        return GetWalletSettingsResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/settings",
            service=self.ENDPOINT,
            component=GetWalletSettingsRequest.Constant.MODULE,
            target_function=GetWalletSettingsRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def delete_wallet_by_user_id(self, request):
        """
        ウォレットを削除します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DeleteWalletByUserIdRequest.DeleteWalletByUserIdRequest
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DeleteWalletByUserIdRequest import DeleteWalletByUserIdRequest
        self._do_delete_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/user/" + str(("null" if request.get_user_id() is None or request.get_user_id() == "" else request.get_user_id())) + "",
            service=self.ENDPOINT,
            component=DeleteWalletByUserIdRequest.Constant.MODULE,
            target_function=DeleteWalletByUserIdRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        )

    def deposit_into_wallet(self, request):
        """
        ウォレットの残高を加算します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DepositIntoWalletRequest.DepositIntoWalletRequest
        :return: 結果
        :rtype: gs2_gold_client.control.DepositIntoWalletResult.DepositIntoWalletResult
        """
        body = { 
            "value": request.get_value(),
        }

        if request.get_context() is not None:
            body["context"] = request.get_context()
        headers = {}
        if request.get_access_token() is not None:
            headers["X-GS2-ACCESS-TOKEN"] = request.get_access_token()
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DepositIntoWalletRequest import DepositIntoWalletRequest
        from gs2_gold_client.control.DepositIntoWalletResult import DepositIntoWalletResult
        return DepositIntoWalletResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/user/self/action/deposit",
            service=self.ENDPOINT,
            component=DepositIntoWalletRequest.Constant.MODULE,
            target_function=DepositIntoWalletRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def deposit_into_wallet_by_stamp_sheet(self, request):
        """
        スタンプタスクを使用してウォレットの残高を加算します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DepositIntoWalletByStampSheetRequest.DepositIntoWalletByStampSheetRequest
        :return: 結果
        :rtype: gs2_gold_client.control.DepositIntoWalletByStampSheetResult.DepositIntoWalletByStampSheetResult
        """
        body = { 
            "sheet": request.get_sheet(),
            "keyName": request.get_key_name(),
        }

        headers = {}
        if request.get_access_token() is not None:
            headers["X-GS2-ACCESS-TOKEN"] = request.get_access_token()
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DepositIntoWalletByStampSheetRequest import DepositIntoWalletByStampSheetRequest
        from gs2_gold_client.control.DepositIntoWalletByStampSheetResult import DepositIntoWalletByStampSheetResult
        return DepositIntoWalletByStampSheetResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/wallet/action/deposit",
            service=self.ENDPOINT,
            component=DepositIntoWalletByStampSheetRequest.Constant.MODULE,
            target_function=DepositIntoWalletByStampSheetRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def deposit_into_wallet_by_user_id(self, request):
        """
        ウォレットの残高を加算します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DepositIntoWalletByUserIdRequest.DepositIntoWalletByUserIdRequest
        :return: 結果
        :rtype: gs2_gold_client.control.DepositIntoWalletByUserIdResult.DepositIntoWalletByUserIdResult
        """
        body = { 
            "value": request.get_value(),
        }

        if request.get_context() is not None:
            body["context"] = request.get_context()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DepositIntoWalletByUserIdRequest import DepositIntoWalletByUserIdRequest
        from gs2_gold_client.control.DepositIntoWalletByUserIdResult import DepositIntoWalletByUserIdResult
        return DepositIntoWalletByUserIdResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/user/" + str(("null" if request.get_user_id() is None or request.get_user_id() == "" else request.get_user_id())) + "/action/deposit",
            service=self.ENDPOINT,
            component=DepositIntoWalletByUserIdRequest.Constant.MODULE,
            target_function=DepositIntoWalletByUserIdRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def describe_wallet(self, request):
        """
        ウォレットの一覧を取得します<br>
        <br>
        - 消費クオータ: 30件あたり10<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DescribeWalletRequest.DescribeWalletRequest
        :return: 結果
        :rtype: gs2_gold_client.control.DescribeWalletResult.DescribeWalletResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_access_token() is not None:
            headers["X-GS2-ACCESS-TOKEN"] = request.get_access_token()
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DescribeWalletRequest import DescribeWalletRequest

        from gs2_gold_client.control.DescribeWalletResult import DescribeWalletResult
        return DescribeWalletResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold",
            service=self.ENDPOINT,
            component=DescribeWalletRequest.Constant.MODULE,
            target_function=DescribeWalletRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def describe_wallet_by_user_id(self, request):
        """
        ウォレットの一覧を取得します<br>
        <br>
        - 消費クオータ: 30件あたり10<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.DescribeWalletByUserIdRequest.DescribeWalletByUserIdRequest
        :return: 結果
        :rtype: gs2_gold_client.control.DescribeWalletByUserIdResult.DescribeWalletByUserIdResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.DescribeWalletByUserIdRequest import DescribeWalletByUserIdRequest

        from gs2_gold_client.control.DescribeWalletByUserIdResult import DescribeWalletByUserIdResult
        return DescribeWalletByUserIdResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/user/" + str(("null" if request.get_user_id() is None or request.get_user_id() == "" else request.get_user_id())) + "",
            service=self.ENDPOINT,
            component=DescribeWalletByUserIdRequest.Constant.MODULE,
            target_function=DescribeWalletByUserIdRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_wallet(self, request):
        """
        ウォレットを取得します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.GetWalletRequest.GetWalletRequest
        :return: 結果
        :rtype: gs2_gold_client.control.GetWalletResult.GetWalletResult
        """
        query_strings = {}
        headers = {}
        if request.get_access_token() is not None:
            headers["X-GS2-ACCESS-TOKEN"] = request.get_access_token()
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.GetWalletRequest import GetWalletRequest

        from gs2_gold_client.control.GetWalletResult import GetWalletResult
        return GetWalletResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/user/self",
            service=self.ENDPOINT,
            component=GetWalletRequest.Constant.MODULE,
            target_function=GetWalletRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_wallet_by_user_id(self, request):
        """
        ウォレットを取得します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gold_client.control.GetWalletByUserIdRequest.GetWalletByUserIdRequest
        :return: 結果
        :rtype: gs2_gold_client.control.GetWalletByUserIdResult.GetWalletByUserIdResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.GetWalletByUserIdRequest import GetWalletByUserIdRequest

        from gs2_gold_client.control.GetWalletByUserIdResult import GetWalletByUserIdResult
        return GetWalletByUserIdResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/user/" + str(("null" if request.get_user_id() is None or request.get_user_id() == "" else request.get_user_id())) + "",
            service=self.ENDPOINT,
            component=GetWalletByUserIdRequest.Constant.MODULE,
            target_function=GetWalletByUserIdRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def set_latest_gain(self, request):
        """
        ウォレットの残高を加算します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.SetLatestGainRequest.SetLatestGainRequest
        :return: 結果
        :rtype: gs2_gold_client.control.SetLatestGainResult.SetLatestGainResult
        """
        body = { 
            "value": request.get_value(),
        }

        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.SetLatestGainRequest import SetLatestGainRequest
        from gs2_gold_client.control.SetLatestGainResult import SetLatestGainResult
        return SetLatestGainResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/user/" + str(("null" if request.get_user_id() is None or request.get_user_id() == "" else request.get_user_id())) + "/action/set",
            service=self.ENDPOINT,
            component=SetLatestGainRequest.Constant.MODULE,
            target_function=SetLatestGainRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def withdraw_from_wallet(self, request):
        """
        ウォレットの残高を減算します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.WithdrawFromWalletRequest.WithdrawFromWalletRequest
        :return: 結果
        :rtype: gs2_gold_client.control.WithdrawFromWalletResult.WithdrawFromWalletResult
        """
        body = { 
            "value": request.get_value(),
        }

        if request.get_context() is not None:
            body["context"] = request.get_context()
        headers = {}
        if request.get_access_token() is not None:
            headers["X-GS2-ACCESS-TOKEN"] = request.get_access_token()
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.WithdrawFromWalletRequest import WithdrawFromWalletRequest
        from gs2_gold_client.control.WithdrawFromWalletResult import WithdrawFromWalletResult
        return WithdrawFromWalletResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/user/self/action/withdraw",
            service=self.ENDPOINT,
            component=WithdrawFromWalletRequest.Constant.MODULE,
            target_function=WithdrawFromWalletRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def withdraw_from_wallet_by_stamp_task(self, request):
        """
        スタンプタスクを使用してウォレットの減算を加算します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.WithdrawFromWalletByStampTaskRequest.WithdrawFromWalletByStampTaskRequest
        :return: 結果
        :rtype: gs2_gold_client.control.WithdrawFromWalletByStampTaskResult.WithdrawFromWalletByStampTaskResult
        """
        body = { 
            "task": request.get_task(),
            "keyName": request.get_key_name(),
            "transactionId": request.get_transaction_id(),
        }

        headers = {}
        if request.get_access_token() is not None:
            headers["X-GS2-ACCESS-TOKEN"] = request.get_access_token()
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.WithdrawFromWalletByStampTaskRequest import WithdrawFromWalletByStampTaskRequest
        from gs2_gold_client.control.WithdrawFromWalletByStampTaskResult import WithdrawFromWalletByStampTaskResult
        return WithdrawFromWalletByStampTaskResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/wallet/action/withdraw",
            service=self.ENDPOINT,
            component=WithdrawFromWalletByStampTaskRequest.Constant.MODULE,
            target_function=WithdrawFromWalletByStampTaskRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def withdraw_from_wallet_by_user_id(self, request):
        """
        ウォレットの残高を減算します<br>
        <br>
        - 消費クオータ: 3<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gold_client.control.WithdrawFromWalletByUserIdRequest.WithdrawFromWalletByUserIdRequest
        :return: 結果
        :rtype: gs2_gold_client.control.WithdrawFromWalletByUserIdResult.WithdrawFromWalletByUserIdResult
        """
        body = { 
            "value": request.get_value(),
        }

        if request.get_context() is not None:
            body["context"] = request.get_context()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gold_client.control.WithdrawFromWalletByUserIdRequest import WithdrawFromWalletByUserIdRequest
        from gs2_gold_client.control.WithdrawFromWalletByUserIdResult import WithdrawFromWalletByUserIdResult
        return WithdrawFromWalletByUserIdResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/goldPool/" + str(("null" if request.get_gold_pool_name() is None or request.get_gold_pool_name() == "" else request.get_gold_pool_name())) + "/gold/" + str(("null" if request.get_gold_name() is None or request.get_gold_name() == "" else request.get_gold_name())) + "/wallet/user/" + str(("null" if request.get_user_id() is None or request.get_user_id() == "" else request.get_user_id())) + "/action/withdraw",
            service=self.ENDPOINT,
            component=WithdrawFromWalletByUserIdRequest.Constant.MODULE,
            target_function=WithdrawFromWalletByUserIdRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))
