# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2UserRequest import Gs2UserRequest
from gs2_gold_client.Gs2Gold import Gs2Gold


class GetWalletRequest(Gs2UserRequest):

    class Constant(Gs2Gold):
        FUNCTION = "GetWallet"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(GetWalletRequest, self).__init__(params)
        if params is None:
            self.__gold_pool_name = None
            self.__gold_name = None
        else:
            self.set_gold_pool_name(params['goldPoolName'] if 'goldPoolName' in params.keys() else None)
            self.set_gold_name(params['goldName'] if 'goldName' in params.keys() else None)

    def get_gold_pool_name(self):
        """
        ゴールドプールの名前を取得
        :return: ゴールドプールの名前
        :rtype: unicode
        """
        return self.__gold_pool_name

    def set_gold_pool_name(self, gold_pool_name):
        """
        ゴールドプールの名前を設定
        :param gold_pool_name: ゴールドプールの名前
        :type gold_pool_name: unicode
        """
        if gold_pool_name is not None and not (isinstance(gold_pool_name, str) or isinstance(gold_pool_name, unicode)):
            raise TypeError(type(gold_pool_name))
        self.__gold_pool_name = gold_pool_name

    def with_gold_pool_name(self, gold_pool_name):
        """
        ゴールドプールの名前を設定
        :param gold_pool_name: ゴールドプールの名前
        :type gold_pool_name: unicode
        :return: this
        :rtype: GetWalletRequest
        """
        self.set_gold_pool_name(gold_pool_name)
        return self

    def get_gold_name(self):
        """
        ゴールドの名前を取得
        :return: ゴールドの名前
        :rtype: unicode
        """
        return self.__gold_name

    def set_gold_name(self, gold_name):
        """
        ゴールドの名前を設定
        :param gold_name: ゴールドの名前
        :type gold_name: unicode
        """
        if gold_name is not None and not (isinstance(gold_name, str) or isinstance(gold_name, unicode)):
            raise TypeError(type(gold_name))
        self.__gold_name = gold_name

    def with_gold_name(self, gold_name):
        """
        ゴールドの名前を設定
        :param gold_name: ゴールドの名前
        :type gold_name: unicode
        :return: this
        :rtype: GetWalletRequest
        """
        self.set_gold_name(gold_name)
        return self
