# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2BasicRequest import Gs2BasicRequest
from gs2_gold_client.Gs2Gold import Gs2Gold


class SetLatestGainRequest(Gs2BasicRequest):

    class Constant(Gs2Gold):
        FUNCTION = "SetLatestGain"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(SetLatestGainRequest, self).__init__(params)
        if params is None:
            self.__gold_pool_name = None
        else:
            self.set_gold_pool_name(params['goldPoolName'] if 'goldPoolName' in params.keys() else None)
        if params is None:
            self.__gold_name = None
        else:
            self.set_gold_name(params['goldName'] if 'goldName' in params.keys() else None)
        if params is None:
            self.__user_id = None
        else:
            self.set_user_id(params['userId'] if 'userId' in params.keys() else None)
        if params is None:
            self.__value = None
        else:
            self.set_value(params['value'] if 'value' in params.keys() else None)

    def get_gold_pool_name(self):
        """
        ゴールドプールの名前を取得
        :return: ゴールドプールの名前
        :rtype: unicode
        """
        return self.__gold_pool_name

    def set_gold_pool_name(self, gold_pool_name):
        """
        ゴールドプールの名前を設定
        :param gold_pool_name: ゴールドプールの名前
        :type gold_pool_name: unicode
        """
        if gold_pool_name is not None and not (isinstance(gold_pool_name, str) or isinstance(gold_pool_name, unicode)):
            raise TypeError(type(gold_pool_name))
        self.__gold_pool_name = gold_pool_name

    def with_gold_pool_name(self, gold_pool_name):
        """
        ゴールドプールの名前を設定
        :param gold_pool_name: ゴールドプールの名前
        :type gold_pool_name: unicode
        :return: this
        :rtype: SetLatestGainRequest
        """
        self.set_gold_pool_name(gold_pool_name)
        return self

    def get_gold_name(self):
        """
        ゴールドの名前を取得
        :return: ゴールドの名前
        :rtype: unicode
        """
        return self.__gold_name

    def set_gold_name(self, gold_name):
        """
        ゴールドの名前を設定
        :param gold_name: ゴールドの名前
        :type gold_name: unicode
        """
        if gold_name is not None and not (isinstance(gold_name, str) or isinstance(gold_name, unicode)):
            raise TypeError(type(gold_name))
        self.__gold_name = gold_name

    def with_gold_name(self, gold_name):
        """
        ゴールドの名前を設定
        :param gold_name: ゴールドの名前
        :type gold_name: unicode
        :return: this
        :rtype: SetLatestGainRequest
        """
        self.set_gold_name(gold_name)
        return self

    def get_user_id(self):
        """
        ウォレット所有者のユーザIDを取得
        :return: ウォレット所有者のユーザID
        :rtype: unicode
        """
        return self.__user_id

    def set_user_id(self, user_id):
        """
        ウォレット所有者のユーザIDを設定
        :param user_id: ウォレット所有者のユーザID
        :type user_id: unicode
        """
        if user_id is not None and not (isinstance(user_id, str) or isinstance(user_id, unicode)):
            raise TypeError(type(user_id))
        self.__user_id = user_id

    def with_user_id(self, user_id):
        """
        ウォレット所有者のユーザIDを設定
        :param user_id: ウォレット所有者のユーザID
        :type user_id: unicode
        :return: this
        :rtype: SetLatestGainRequest
        """
        self.set_user_id(user_id)
        return self

    def get_value(self):
        """
        期間内の取得量を取得
        :return: 期間内の取得量
        :rtype: long
        """
        return self.__value

    def set_value(self, value):
        """
        期間内の取得量を設定
        :param value: 期間内の取得量
        :type value: long
        """
        if value is not None and not (isinstance(value, int) or isinstance(value, long)):
            raise TypeError(type(value))
        self.__value = value

    def with_value(self, value):
        """
        期間内の取得量を設定
        :param value: 期間内の取得量
        :type value: long
        :return: this
        :rtype: SetLatestGainRequest
        """
        self.set_value(value)
        return self
