# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2BasicRequest import Gs2BasicRequest
from gs2_gold_client.Gs2Gold import Gs2Gold


class UpdateGoldMasterRequest(Gs2BasicRequest):

    class Constant(Gs2Gold):
        FUNCTION = "UpdateGoldMaster"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(UpdateGoldMasterRequest, self).__init__(params)
        if params is None:
            self.__gold_pool_name = None
        else:
            self.set_gold_pool_name(params['goldPoolName'] if 'goldPoolName' in params.keys() else None)
        if params is None:
            self.__gold_name = None
        else:
            self.set_gold_name(params['goldName'] if 'goldName' in params.keys() else None)
        if params is None:
            self.__meta = None
        else:
            self.set_meta(params['meta'] if 'meta' in params.keys() else None)
        if params is None:
            self.__balance_max = None
        else:
            self.set_balance_max(params['balanceMax'] if 'balanceMax' in params.keys() else None)
        if params is None:
            self.__reset_type = None
        else:
            self.set_reset_type(params['resetType'] if 'resetType' in params.keys() else None)
        if params is None:
            self.__reset_day_of_month = None
        else:
            self.set_reset_day_of_month(params['resetDayOfMonth'] if 'resetDayOfMonth' in params.keys() else None)
        if params is None:
            self.__reset_day_of_week = None
        else:
            self.set_reset_day_of_week(params['resetDayOfWeek'] if 'resetDayOfWeek' in params.keys() else None)
        if params is None:
            self.__reset_hour = None
        else:
            self.set_reset_hour(params['resetHour'] if 'resetHour' in params.keys() else None)
        if params is None:
            self.__latest_gain_max = None
        else:
            self.set_latest_gain_max(params['latestGainMax'] if 'latestGainMax' in params.keys() else None)
        if params is None:
            self.__create_wallet_trigger_script = None
        else:
            self.set_create_wallet_trigger_script(params['createWalletTriggerScript'] if 'createWalletTriggerScript' in params.keys() else None)
        if params is None:
            self.__create_wallet_done_trigger_script = None
        else:
            self.set_create_wallet_done_trigger_script(params['createWalletDoneTriggerScript'] if 'createWalletDoneTriggerScript' in params.keys() else None)
        if params is None:
            self.__deposit_into_wallet_trigger_script = None
        else:
            self.set_deposit_into_wallet_trigger_script(params['depositIntoWalletTriggerScript'] if 'depositIntoWalletTriggerScript' in params.keys() else None)
        if params is None:
            self.__deposit_into_wallet_done_trigger_script = None
        else:
            self.set_deposit_into_wallet_done_trigger_script(params['depositIntoWalletDoneTriggerScript'] if 'depositIntoWalletDoneTriggerScript' in params.keys() else None)
        if params is None:
            self.__withdraw_from_wallet_trigger_script = None
        else:
            self.set_withdraw_from_wallet_trigger_script(params['withdrawFromWalletTriggerScript'] if 'withdrawFromWalletTriggerScript' in params.keys() else None)
        if params is None:
            self.__withdraw_from_wallet_done_trigger_script = None
        else:
            self.set_withdraw_from_wallet_done_trigger_script(params['withdrawFromWalletDoneTriggerScript'] if 'withdrawFromWalletDoneTriggerScript' in params.keys() else None)

    def get_gold_pool_name(self):
        """
        ゴールドプールの名前を取得
        :return: ゴールドプールの名前
        :rtype: unicode
        """
        return self.__gold_pool_name

    def set_gold_pool_name(self, gold_pool_name):
        """
        ゴールドプールの名前を設定
        :param gold_pool_name: ゴールドプールの名前
        :type gold_pool_name: unicode
        """
        if gold_pool_name is not None and not (isinstance(gold_pool_name, str) or isinstance(gold_pool_name, unicode)):
            raise TypeError(type(gold_pool_name))
        self.__gold_pool_name = gold_pool_name

    def with_gold_pool_name(self, gold_pool_name):
        """
        ゴールドプールの名前を設定
        :param gold_pool_name: ゴールドプールの名前
        :type gold_pool_name: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_gold_pool_name(gold_pool_name)
        return self

    def get_gold_name(self):
        """
        ゴールドの名前を取得
        :return: ゴールドの名前
        :rtype: unicode
        """
        return self.__gold_name

    def set_gold_name(self, gold_name):
        """
        ゴールドの名前を設定
        :param gold_name: ゴールドの名前
        :type gold_name: unicode
        """
        if gold_name is not None and not (isinstance(gold_name, str) or isinstance(gold_name, unicode)):
            raise TypeError(type(gold_name))
        self.__gold_name = gold_name

    def with_gold_name(self, gold_name):
        """
        ゴールドの名前を設定
        :param gold_name: ゴールドの名前
        :type gold_name: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_gold_name(gold_name)
        return self

    def get_meta(self):
        """
        メタデータを取得
        :return: メタデータ
        :rtype: unicode
        """
        return self.__meta

    def set_meta(self, meta):
        """
        メタデータを設定
        :param meta: メタデータ
        :type meta: unicode
        """
        if meta is not None and not (isinstance(meta, str) or isinstance(meta, unicode)):
            raise TypeError(type(meta))
        self.__meta = meta

    def with_meta(self, meta):
        """
        メタデータを設定
        :param meta: メタデータ
        :type meta: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_meta(meta)
        return self

    def get_balance_max(self):
        """
        各ウォレットの残高の最大値を取得
        :return: 各ウォレットの残高の最大値
        :rtype: long
        """
        return self.__balance_max

    def set_balance_max(self, balance_max):
        """
        各ウォレットの残高の最大値を設定
        :param balance_max: 各ウォレットの残高の最大値
        :type balance_max: long
        """
        if balance_max is not None and not (isinstance(balance_max, int) or isinstance(balance_max, long)):
            raise TypeError(type(balance_max))
        self.__balance_max = balance_max

    def with_balance_max(self, balance_max):
        """
        各ウォレットの残高の最大値を設定
        :param balance_max: 各ウォレットの残高の最大値
        :type balance_max: long
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_balance_max(balance_max)
        return self

    def get_reset_type(self):
        """
        取得量の期間制限のタイプを取得
        :return: 取得量の期間制限のタイプ
        :rtype: unicode
        """
        return self.__reset_type

    def set_reset_type(self, reset_type):
        """
        取得量の期間制限のタイプを設定
        :param reset_type: 取得量の期間制限のタイプ
        :type reset_type: unicode
        """
        if reset_type is not None and not (isinstance(reset_type, str) or isinstance(reset_type, unicode)):
            raise TypeError(type(reset_type))
        self.__reset_type = reset_type

    def with_reset_type(self, reset_type):
        """
        取得量の期間制限のタイプを設定
        :param reset_type: 取得量の期間制限のタイプ
        :type reset_type: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_reset_type(reset_type)
        return self

    def get_reset_day_of_month(self):
        """
        期間内の取得量をリセットする日にちを取得
        :return: 期間内の取得量をリセットする日にち
        :rtype: int
        """
        return self.__reset_day_of_month

    def set_reset_day_of_month(self, reset_day_of_month):
        """
        期間内の取得量をリセットする日にちを設定
        :param reset_day_of_month: 期間内の取得量をリセットする日にち
        :type reset_day_of_month: int
        """
        if reset_day_of_month is not None and not isinstance(reset_day_of_month, int):
            raise TypeError(type(reset_day_of_month))
        self.__reset_day_of_month = reset_day_of_month

    def with_reset_day_of_month(self, reset_day_of_month):
        """
        期間内の取得量をリセットする日にちを設定
        :param reset_day_of_month: 期間内の取得量をリセットする日にち
        :type reset_day_of_month: int
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_reset_day_of_month(reset_day_of_month)
        return self

    def get_reset_day_of_week(self):
        """
        期間内の取得量をリセットする曜日を取得
        :return: 期間内の取得量をリセットする曜日
        :rtype: unicode
        """
        return self.__reset_day_of_week

    def set_reset_day_of_week(self, reset_day_of_week):
        """
        期間内の取得量をリセットする曜日を設定
        :param reset_day_of_week: 期間内の取得量をリセットする曜日
        :type reset_day_of_week: unicode
        """
        if reset_day_of_week is not None and not (isinstance(reset_day_of_week, str) or isinstance(reset_day_of_week, unicode)):
            raise TypeError(type(reset_day_of_week))
        self.__reset_day_of_week = reset_day_of_week

    def with_reset_day_of_week(self, reset_day_of_week):
        """
        期間内の取得量をリセットする曜日を設定
        :param reset_day_of_week: 期間内の取得量をリセットする曜日
        :type reset_day_of_week: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_reset_day_of_week(reset_day_of_week)
        return self

    def get_reset_hour(self):
        """
        期間内の取得量をリセットする時を取得
        :return: 期間内の取得量をリセットする時
        :rtype: int
        """
        return self.__reset_hour

    def set_reset_hour(self, reset_hour):
        """
        期間内の取得量をリセットする時を設定
        :param reset_hour: 期間内の取得量をリセットする時
        :type reset_hour: int
        """
        if reset_hour is not None and not isinstance(reset_hour, int):
            raise TypeError(type(reset_hour))
        self.__reset_hour = reset_hour

    def with_reset_hour(self, reset_hour):
        """
        期間内の取得量をリセットする時を設定
        :param reset_hour: 期間内の取得量をリセットする時
        :type reset_hour: int
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_reset_hour(reset_hour)
        return self

    def get_latest_gain_max(self):
        """
        期間内の最大取得量を取得
        :return: 期間内の最大取得量
        :rtype: long
        """
        return self.__latest_gain_max

    def set_latest_gain_max(self, latest_gain_max):
        """
        期間内の最大取得量を設定
        :param latest_gain_max: 期間内の最大取得量
        :type latest_gain_max: long
        """
        if latest_gain_max is not None and not (isinstance(latest_gain_max, int) or isinstance(latest_gain_max, long)):
            raise TypeError(type(latest_gain_max))
        self.__latest_gain_max = latest_gain_max

    def with_latest_gain_max(self, latest_gain_max):
        """
        期間内の最大取得量を設定
        :param latest_gain_max: 期間内の最大取得量
        :type latest_gain_max: long
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_latest_gain_max(latest_gain_max)
        return self

    def get_create_wallet_trigger_script(self):
        """
        ウォレットの生成時 に実行されるGS2-Scriptを取得
        :return: ウォレットの生成時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__create_wallet_trigger_script

    def set_create_wallet_trigger_script(self, create_wallet_trigger_script):
        """
        ウォレットの生成時 に実行されるGS2-Scriptを設定
        :param create_wallet_trigger_script: ウォレットの生成時 に実行されるGS2-Script
        :type create_wallet_trigger_script: unicode
        """
        if create_wallet_trigger_script is not None and not (isinstance(create_wallet_trigger_script, str) or isinstance(create_wallet_trigger_script, unicode)):
            raise TypeError(type(create_wallet_trigger_script))
        self.__create_wallet_trigger_script = create_wallet_trigger_script

    def with_create_wallet_trigger_script(self, create_wallet_trigger_script):
        """
        ウォレットの生成時 に実行されるGS2-Scriptを設定
        :param create_wallet_trigger_script: ウォレットの生成時 に実行されるGS2-Script
        :type create_wallet_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_create_wallet_trigger_script(create_wallet_trigger_script)
        return self

    def get_create_wallet_done_trigger_script(self):
        """
        ウォレットの生成完了時 に実行されるGS2-Scriptを取得
        :return: ウォレットの生成完了時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__create_wallet_done_trigger_script

    def set_create_wallet_done_trigger_script(self, create_wallet_done_trigger_script):
        """
        ウォレットの生成完了時 に実行されるGS2-Scriptを設定
        :param create_wallet_done_trigger_script: ウォレットの生成完了時 に実行されるGS2-Script
        :type create_wallet_done_trigger_script: unicode
        """
        if create_wallet_done_trigger_script is not None and not (isinstance(create_wallet_done_trigger_script, str) or isinstance(create_wallet_done_trigger_script, unicode)):
            raise TypeError(type(create_wallet_done_trigger_script))
        self.__create_wallet_done_trigger_script = create_wallet_done_trigger_script

    def with_create_wallet_done_trigger_script(self, create_wallet_done_trigger_script):
        """
        ウォレットの生成完了時 に実行されるGS2-Scriptを設定
        :param create_wallet_done_trigger_script: ウォレットの生成完了時 に実行されるGS2-Script
        :type create_wallet_done_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_create_wallet_done_trigger_script(create_wallet_done_trigger_script)
        return self

    def get_deposit_into_wallet_trigger_script(self):
        """
        ウォレットへの加算時 に実行されるGS2-Scriptを取得
        :return: ウォレットへの加算時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__deposit_into_wallet_trigger_script

    def set_deposit_into_wallet_trigger_script(self, deposit_into_wallet_trigger_script):
        """
        ウォレットへの加算時 に実行されるGS2-Scriptを設定
        :param deposit_into_wallet_trigger_script: ウォレットへの加算時 に実行されるGS2-Script
        :type deposit_into_wallet_trigger_script: unicode
        """
        if deposit_into_wallet_trigger_script is not None and not (isinstance(deposit_into_wallet_trigger_script, str) or isinstance(deposit_into_wallet_trigger_script, unicode)):
            raise TypeError(type(deposit_into_wallet_trigger_script))
        self.__deposit_into_wallet_trigger_script = deposit_into_wallet_trigger_script

    def with_deposit_into_wallet_trigger_script(self, deposit_into_wallet_trigger_script):
        """
        ウォレットへの加算時 に実行されるGS2-Scriptを設定
        :param deposit_into_wallet_trigger_script: ウォレットへの加算時 に実行されるGS2-Script
        :type deposit_into_wallet_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_deposit_into_wallet_trigger_script(deposit_into_wallet_trigger_script)
        return self

    def get_deposit_into_wallet_done_trigger_script(self):
        """
        ウォレットへの加算完了時 に実行されるGS2-Scriptを取得
        :return: ウォレットへの加算完了時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__deposit_into_wallet_done_trigger_script

    def set_deposit_into_wallet_done_trigger_script(self, deposit_into_wallet_done_trigger_script):
        """
        ウォレットへの加算完了時 に実行されるGS2-Scriptを設定
        :param deposit_into_wallet_done_trigger_script: ウォレットへの加算完了時 に実行されるGS2-Script
        :type deposit_into_wallet_done_trigger_script: unicode
        """
        if deposit_into_wallet_done_trigger_script is not None and not (isinstance(deposit_into_wallet_done_trigger_script, str) or isinstance(deposit_into_wallet_done_trigger_script, unicode)):
            raise TypeError(type(deposit_into_wallet_done_trigger_script))
        self.__deposit_into_wallet_done_trigger_script = deposit_into_wallet_done_trigger_script

    def with_deposit_into_wallet_done_trigger_script(self, deposit_into_wallet_done_trigger_script):
        """
        ウォレットへの加算完了時 に実行されるGS2-Scriptを設定
        :param deposit_into_wallet_done_trigger_script: ウォレットへの加算完了時 に実行されるGS2-Script
        :type deposit_into_wallet_done_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_deposit_into_wallet_done_trigger_script(deposit_into_wallet_done_trigger_script)
        return self

    def get_withdraw_from_wallet_trigger_script(self):
        """
        ウォレットからの減算時 に実行されるGS2-Scriptを取得
        :return: ウォレットからの減算時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__withdraw_from_wallet_trigger_script

    def set_withdraw_from_wallet_trigger_script(self, withdraw_from_wallet_trigger_script):
        """
        ウォレットからの減算時 に実行されるGS2-Scriptを設定
        :param withdraw_from_wallet_trigger_script: ウォレットからの減算時 に実行されるGS2-Script
        :type withdraw_from_wallet_trigger_script: unicode
        """
        if withdraw_from_wallet_trigger_script is not None and not (isinstance(withdraw_from_wallet_trigger_script, str) or isinstance(withdraw_from_wallet_trigger_script, unicode)):
            raise TypeError(type(withdraw_from_wallet_trigger_script))
        self.__withdraw_from_wallet_trigger_script = withdraw_from_wallet_trigger_script

    def with_withdraw_from_wallet_trigger_script(self, withdraw_from_wallet_trigger_script):
        """
        ウォレットからの減算時 に実行されるGS2-Scriptを設定
        :param withdraw_from_wallet_trigger_script: ウォレットからの減算時 に実行されるGS2-Script
        :type withdraw_from_wallet_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_withdraw_from_wallet_trigger_script(withdraw_from_wallet_trigger_script)
        return self

    def get_withdraw_from_wallet_done_trigger_script(self):
        """
        ウォレットからの減算完了時 に実行されるGS2-Scriptを取得
        :return: ウォレットからの減算完了時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__withdraw_from_wallet_done_trigger_script

    def set_withdraw_from_wallet_done_trigger_script(self, withdraw_from_wallet_done_trigger_script):
        """
        ウォレットからの減算完了時 に実行されるGS2-Scriptを設定
        :param withdraw_from_wallet_done_trigger_script: ウォレットからの減算完了時 に実行されるGS2-Script
        :type withdraw_from_wallet_done_trigger_script: unicode
        """
        if withdraw_from_wallet_done_trigger_script is not None and not (isinstance(withdraw_from_wallet_done_trigger_script, str) or isinstance(withdraw_from_wallet_done_trigger_script, unicode)):
            raise TypeError(type(withdraw_from_wallet_done_trigger_script))
        self.__withdraw_from_wallet_done_trigger_script = withdraw_from_wallet_done_trigger_script

    def with_withdraw_from_wallet_done_trigger_script(self, withdraw_from_wallet_done_trigger_script):
        """
        ウォレットからの減算完了時 に実行されるGS2-Scriptを設定
        :param withdraw_from_wallet_done_trigger_script: ウォレットからの減算完了時 に実行されるGS2-Script
        :type withdraw_from_wallet_done_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldMasterRequest
        """
        self.set_withdraw_from_wallet_done_trigger_script(withdraw_from_wallet_done_trigger_script)
        return self
