# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2BasicRequest import Gs2BasicRequest
from gs2_gold_client.Gs2Gold import Gs2Gold


class UpdateGoldPoolRequest(Gs2BasicRequest):

    class Constant(Gs2Gold):
        FUNCTION = "UpdateGoldPool"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(UpdateGoldPoolRequest, self).__init__(params)
        if params is None:
            self.__gold_pool_name = None
        else:
            self.set_gold_pool_name(params['goldPoolName'] if 'goldPoolName' in params.keys() else None)
        if params is None:
            self.__description = None
        else:
            self.set_description(params['description'] if 'description' in params.keys() else None)
        if params is None:
            self.__service_class = None
        else:
            self.set_service_class(params['serviceClass'] if 'serviceClass' in params.keys() else None)
        if params is None:
            self.__create_wallet_trigger_script = None
        else:
            self.set_create_wallet_trigger_script(params['createWalletTriggerScript'] if 'createWalletTriggerScript' in params.keys() else None)
        if params is None:
            self.__create_wallet_done_trigger_script = None
        else:
            self.set_create_wallet_done_trigger_script(params['createWalletDoneTriggerScript'] if 'createWalletDoneTriggerScript' in params.keys() else None)
        if params is None:
            self.__deposit_into_wallet_trigger_script = None
        else:
            self.set_deposit_into_wallet_trigger_script(params['depositIntoWalletTriggerScript'] if 'depositIntoWalletTriggerScript' in params.keys() else None)
        if params is None:
            self.__deposit_into_wallet_done_trigger_script = None
        else:
            self.set_deposit_into_wallet_done_trigger_script(params['depositIntoWalletDoneTriggerScript'] if 'depositIntoWalletDoneTriggerScript' in params.keys() else None)
        if params is None:
            self.__withdraw_from_wallet_trigger_script = None
        else:
            self.set_withdraw_from_wallet_trigger_script(params['withdrawFromWalletTriggerScript'] if 'withdrawFromWalletTriggerScript' in params.keys() else None)
        if params is None:
            self.__withdraw_from_wallet_done_trigger_script = None
        else:
            self.set_withdraw_from_wallet_done_trigger_script(params['withdrawFromWalletDoneTriggerScript'] if 'withdrawFromWalletDoneTriggerScript' in params.keys() else None)

    def get_gold_pool_name(self):
        """
        ゴールドプールの名前を取得
        :return: ゴールドプールの名前
        :rtype: unicode
        """
        return self.__gold_pool_name

    def set_gold_pool_name(self, gold_pool_name):
        """
        ゴールドプールの名前を設定
        :param gold_pool_name: ゴールドプールの名前
        :type gold_pool_name: unicode
        """
        if gold_pool_name is not None and not (isinstance(gold_pool_name, str) or isinstance(gold_pool_name, unicode)):
            raise TypeError(type(gold_pool_name))
        self.__gold_pool_name = gold_pool_name

    def with_gold_pool_name(self, gold_pool_name):
        """
        ゴールドプールの名前を設定
        :param gold_pool_name: ゴールドプールの名前
        :type gold_pool_name: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_gold_pool_name(gold_pool_name)
        return self

    def get_description(self):
        """
        説明文を取得
        :return: 説明文
        :rtype: unicode
        """
        return self.__description

    def set_description(self, description):
        """
        説明文を設定
        :param description: 説明文
        :type description: unicode
        """
        if description is not None and not (isinstance(description, str) or isinstance(description, unicode)):
            raise TypeError(type(description))
        self.__description = description

    def with_description(self, description):
        """
        説明文を設定
        :param description: 説明文
        :type description: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_description(description)
        return self

    def get_service_class(self):
        """
        サービスクラスを取得
        :return: サービスクラス
        :rtype: unicode
        """
        return self.__service_class

    def set_service_class(self, service_class):
        """
        サービスクラスを設定
        :param service_class: サービスクラス
        :type service_class: unicode
        """
        if service_class is not None and not (isinstance(service_class, str) or isinstance(service_class, unicode)):
            raise TypeError(type(service_class))
        self.__service_class = service_class

    def with_service_class(self, service_class):
        """
        サービスクラスを設定
        :param service_class: サービスクラス
        :type service_class: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_service_class(service_class)
        return self

    def get_create_wallet_trigger_script(self):
        """
        ウォレットの生成時 に実行されるGS2-Scriptを取得
        :return: ウォレットの生成時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__create_wallet_trigger_script

    def set_create_wallet_trigger_script(self, create_wallet_trigger_script):
        """
        ウォレットの生成時 に実行されるGS2-Scriptを設定
        :param create_wallet_trigger_script: ウォレットの生成時 に実行されるGS2-Script
        :type create_wallet_trigger_script: unicode
        """
        if create_wallet_trigger_script is not None and not (isinstance(create_wallet_trigger_script, str) or isinstance(create_wallet_trigger_script, unicode)):
            raise TypeError(type(create_wallet_trigger_script))
        self.__create_wallet_trigger_script = create_wallet_trigger_script

    def with_create_wallet_trigger_script(self, create_wallet_trigger_script):
        """
        ウォレットの生成時 に実行されるGS2-Scriptを設定
        :param create_wallet_trigger_script: ウォレットの生成時 に実行されるGS2-Script
        :type create_wallet_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_create_wallet_trigger_script(create_wallet_trigger_script)
        return self

    def get_create_wallet_done_trigger_script(self):
        """
        ウォレットの生成完了時 に実行されるGS2-Scriptを取得
        :return: ウォレットの生成完了時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__create_wallet_done_trigger_script

    def set_create_wallet_done_trigger_script(self, create_wallet_done_trigger_script):
        """
        ウォレットの生成完了時 に実行されるGS2-Scriptを設定
        :param create_wallet_done_trigger_script: ウォレットの生成完了時 に実行されるGS2-Script
        :type create_wallet_done_trigger_script: unicode
        """
        if create_wallet_done_trigger_script is not None and not (isinstance(create_wallet_done_trigger_script, str) or isinstance(create_wallet_done_trigger_script, unicode)):
            raise TypeError(type(create_wallet_done_trigger_script))
        self.__create_wallet_done_trigger_script = create_wallet_done_trigger_script

    def with_create_wallet_done_trigger_script(self, create_wallet_done_trigger_script):
        """
        ウォレットの生成完了時 に実行されるGS2-Scriptを設定
        :param create_wallet_done_trigger_script: ウォレットの生成完了時 に実行されるGS2-Script
        :type create_wallet_done_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_create_wallet_done_trigger_script(create_wallet_done_trigger_script)
        return self

    def get_deposit_into_wallet_trigger_script(self):
        """
        ウォレットへの加算時 に実行されるGS2-Scriptを取得
        :return: ウォレットへの加算時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__deposit_into_wallet_trigger_script

    def set_deposit_into_wallet_trigger_script(self, deposit_into_wallet_trigger_script):
        """
        ウォレットへの加算時 に実行されるGS2-Scriptを設定
        :param deposit_into_wallet_trigger_script: ウォレットへの加算時 に実行されるGS2-Script
        :type deposit_into_wallet_trigger_script: unicode
        """
        if deposit_into_wallet_trigger_script is not None and not (isinstance(deposit_into_wallet_trigger_script, str) or isinstance(deposit_into_wallet_trigger_script, unicode)):
            raise TypeError(type(deposit_into_wallet_trigger_script))
        self.__deposit_into_wallet_trigger_script = deposit_into_wallet_trigger_script

    def with_deposit_into_wallet_trigger_script(self, deposit_into_wallet_trigger_script):
        """
        ウォレットへの加算時 に実行されるGS2-Scriptを設定
        :param deposit_into_wallet_trigger_script: ウォレットへの加算時 に実行されるGS2-Script
        :type deposit_into_wallet_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_deposit_into_wallet_trigger_script(deposit_into_wallet_trigger_script)
        return self

    def get_deposit_into_wallet_done_trigger_script(self):
        """
        ウォレットへの加算完了時 に実行されるGS2-Scriptを取得
        :return: ウォレットへの加算完了時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__deposit_into_wallet_done_trigger_script

    def set_deposit_into_wallet_done_trigger_script(self, deposit_into_wallet_done_trigger_script):
        """
        ウォレットへの加算完了時 に実行されるGS2-Scriptを設定
        :param deposit_into_wallet_done_trigger_script: ウォレットへの加算完了時 に実行されるGS2-Script
        :type deposit_into_wallet_done_trigger_script: unicode
        """
        if deposit_into_wallet_done_trigger_script is not None and not (isinstance(deposit_into_wallet_done_trigger_script, str) or isinstance(deposit_into_wallet_done_trigger_script, unicode)):
            raise TypeError(type(deposit_into_wallet_done_trigger_script))
        self.__deposit_into_wallet_done_trigger_script = deposit_into_wallet_done_trigger_script

    def with_deposit_into_wallet_done_trigger_script(self, deposit_into_wallet_done_trigger_script):
        """
        ウォレットへの加算完了時 に実行されるGS2-Scriptを設定
        :param deposit_into_wallet_done_trigger_script: ウォレットへの加算完了時 に実行されるGS2-Script
        :type deposit_into_wallet_done_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_deposit_into_wallet_done_trigger_script(deposit_into_wallet_done_trigger_script)
        return self

    def get_withdraw_from_wallet_trigger_script(self):
        """
        ウォレットからの減算時 に実行されるGS2-Scriptを取得
        :return: ウォレットからの減算時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__withdraw_from_wallet_trigger_script

    def set_withdraw_from_wallet_trigger_script(self, withdraw_from_wallet_trigger_script):
        """
        ウォレットからの減算時 に実行されるGS2-Scriptを設定
        :param withdraw_from_wallet_trigger_script: ウォレットからの減算時 に実行されるGS2-Script
        :type withdraw_from_wallet_trigger_script: unicode
        """
        if withdraw_from_wallet_trigger_script is not None and not (isinstance(withdraw_from_wallet_trigger_script, str) or isinstance(withdraw_from_wallet_trigger_script, unicode)):
            raise TypeError(type(withdraw_from_wallet_trigger_script))
        self.__withdraw_from_wallet_trigger_script = withdraw_from_wallet_trigger_script

    def with_withdraw_from_wallet_trigger_script(self, withdraw_from_wallet_trigger_script):
        """
        ウォレットからの減算時 に実行されるGS2-Scriptを設定
        :param withdraw_from_wallet_trigger_script: ウォレットからの減算時 に実行されるGS2-Script
        :type withdraw_from_wallet_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_withdraw_from_wallet_trigger_script(withdraw_from_wallet_trigger_script)
        return self

    def get_withdraw_from_wallet_done_trigger_script(self):
        """
        ウォレットからの減算完了時 に実行されるGS2-Scriptを取得
        :return: ウォレットからの減算完了時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__withdraw_from_wallet_done_trigger_script

    def set_withdraw_from_wallet_done_trigger_script(self, withdraw_from_wallet_done_trigger_script):
        """
        ウォレットからの減算完了時 に実行されるGS2-Scriptを設定
        :param withdraw_from_wallet_done_trigger_script: ウォレットからの減算完了時 に実行されるGS2-Script
        :type withdraw_from_wallet_done_trigger_script: unicode
        """
        if withdraw_from_wallet_done_trigger_script is not None and not (isinstance(withdraw_from_wallet_done_trigger_script, str) or isinstance(withdraw_from_wallet_done_trigger_script, unicode)):
            raise TypeError(type(withdraw_from_wallet_done_trigger_script))
        self.__withdraw_from_wallet_done_trigger_script = withdraw_from_wallet_done_trigger_script

    def with_withdraw_from_wallet_done_trigger_script(self, withdraw_from_wallet_done_trigger_script):
        """
        ウォレットからの減算完了時 に実行されるGS2-Scriptを設定
        :param withdraw_from_wallet_done_trigger_script: ウォレットからの減算完了時 に実行されるGS2-Script
        :type withdraw_from_wallet_done_trigger_script: unicode
        :return: this
        :rtype: UpdateGoldPoolRequest
        """
        self.set_withdraw_from_wallet_done_trigger_script(withdraw_from_wallet_done_trigger_script)
        return self
