# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2UserRequest import Gs2UserRequest
from gs2_gold_client.Gs2Gold import Gs2Gold


class WithdrawFromMyWalletRequest(Gs2UserRequest):

    class Constant(Gs2Gold):
        FUNCTION = "WithdrawFromMyWallet"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(WithdrawFromMyWalletRequest, self).__init__(params)
        if params is None:
            self.__gold_name = None
            self.__value = None
            self.__context = None
        else:
            self.set_gold_name(params['goldName'] if 'goldName' in params.keys() else None)
            self.set_value(params['value'] if 'value' in params.keys() else None)
            self.set_context(params['context'] if 'context' in params.keys() else None)

    def get_gold_name(self):
        """
        ゴールドの名前を指定します。を取得
        :return: ゴールドの名前を指定します。
        :rtype: unicode
        """
        return self.__gold_name

    def set_gold_name(self, gold_name):
        """
        ゴールドの名前を指定します。を設定
        :param gold_name: ゴールドの名前を指定します。
        :type gold_name: unicode
        """
        if gold_name and not (isinstance(gold_name, str) or isinstance(gold_name, unicode)):
            raise TypeError(type(gold_name))
        self.__gold_name = gold_name

    def with_gold_name(self, gold_name):
        """
        ゴールドの名前を指定します。を設定
        :param gold_name: ゴールドの名前を指定します。
        :type gold_name: unicode
        :return: this
        :rtype: WithdrawFromMyWalletRequest
        """
        self.set_gold_name(gold_name)
        return self

    def get_value(self):
        """
        減算量を取得
        :return: 減算量
        :rtype: long
        """
        return self.__value

    def set_value(self, value):
        """
        減算量を設定
        :param value: 減算量
        :type value: long
        """
        if value and not (isinstance(value, int) or isinstance(value, long)):
            raise TypeError(type(value))
        self.__value = value

    def with_value(self, value):
        """
        減算量を設定
        :param value: 減算量
        :type value: long
        :return: this
        :rtype: WithdrawFromMyWalletRequest
        """
        self.set_value(value)
        return self

    def get_context(self):
        """
        コンテキストを取得
        :return: コンテキスト
        :rtype: unicode
        """
        return self.__context

    def set_context(self, context):
        """
        コンテキストを設定
        :param context: コンテキスト
        :type context: unicode
        """
        if context and not (isinstance(context, str) or isinstance(context, unicode)):
            raise TypeError(type(context))
        self.__context = context

    def with_context(self, context):
        """
        コンテキストを設定
        :param context: コンテキスト
        :type context: unicode
        :return: this
        :rtype: WithdrawFromMyWalletRequest
        """
        self.set_context(context)
        return self
