# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.


class Wallet(object):

    def __init__(self, params=None):
        if params is None:
            self.__wallet_id = None
            self.__user_id = None
            self.__gold_name = None
            self.__meta = None
            self.__balance = None
            self.__latest_gain = None
            self.__create_at = None
            self.__update_at = None
        else:
            self.set_wallet_id(params['walletId'] if 'walletId' in params.keys() else None)
            self.set_user_id(params['userId'] if 'userId' in params.keys() else None)
            self.set_gold_name(params['goldName'] if 'goldName' in params.keys() else None)
            self.set_meta(params['meta'] if 'meta' in params.keys() else None)
            self.set_balance(params['balance'] if 'balance' in params.keys() else None)
            self.set_latest_gain(params['latestGain'] if 'latestGain' in params.keys() else None)
            self.set_create_at(params['createAt'] if 'createAt' in params.keys() else None)
            self.set_update_at(params['updateAt'] if 'updateAt' in params.keys() else None)

    def get_wallet_id(self):
        """
        ウォレットGRNを取得
        :return: ウォレットGRN
        :rtype: unicode
        """
        return self.__wallet_id

    def set_wallet_id(self, wallet_id):
        """
        ウォレットGRNを設定
        :param wallet_id: ウォレットGRN
        :type wallet_id: unicode
        """
        self.__wallet_id = wallet_id

    def get_user_id(self):
        """
        ユーザIDを取得
        :return: ユーザID
        :rtype: unicode
        """
        return self.__user_id

    def set_user_id(self, user_id):
        """
        ユーザIDを設定
        :param user_id: ユーザID
        :type user_id: unicode
        """
        self.__user_id = user_id

    def get_gold_name(self):
        """
        ゴールド名を取得
        :return: ゴールド名
        :rtype: unicode
        """
        return self.__gold_name

    def set_gold_name(self, gold_name):
        """
        ゴールド名を設定
        :param gold_name: ゴールド名
        :type gold_name: unicode
        """
        self.__gold_name = gold_name

    def get_meta(self):
        """
        メタデータを取得
        :return: メタデータ
        :rtype: unicode
        """
        return self.__meta

    def set_meta(self, meta):
        """
        メタデータを設定
        :param meta: メタデータ
        :type meta: unicode
        """
        self.__meta = meta

    def get_balance(self):
        """
        残高を取得
        :return: 残高
        :rtype: long
        """
        return self.__balance

    def set_balance(self, balance):
        """
        残高を設定
        :param balance: 残高
        :type balance: long
        """
        self.__balance = balance

    def get_latest_gain(self):
        """
        直近の期間の取得量を取得
        :return: 直近の期間の取得量
        :rtype: long
        """
        return self.__latest_gain

    def set_latest_gain(self, latest_gain):
        """
        直近の期間の取得量を設定
        :param latest_gain: 直近の期間の取得量
        :type latest_gain: long
        """
        self.__latest_gain = latest_gain

    def get_create_at(self):
        """
        作成日時(エポック秒)を取得
        :return: 作成日時(エポック秒)
        :rtype: int
        """
        return self.__create_at

    def set_create_at(self, create_at):
        """
        作成日時(エポック秒)を設定
        :param create_at: 作成日時(エポック秒)
        :type create_at: int
        """
        self.__create_at = create_at

    def get_update_at(self):
        """
        最終更新日時(エポック秒)を取得
        :return: 最終更新日時(エポック秒)
        :rtype: int
        """
        return self.__update_at

    def set_update_at(self, update_at):
        """
        最終更新日時(エポック秒)を設定
        :param update_at: 最終更新日時(エポック秒)
        :type update_at: int
        """
        self.__update_at = update_at

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return super(Wallet, self).__getitem__(key)

    def to_dict(self):
        return {
            "walletId": self.__wallet_id,
            "userId": self.__user_id,
            "goldName": self.__gold_name,
            "meta": self.__meta,
            "balance": self.__balance,
            "latestGain": self.__latest_gain,
            "createAt": self.__create_at,
            "updateAt": self.__update_at,
        }
