# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.


class WalletSettings(object):

    def __init__(self, params=None):
        if params is None:
            self.__gold_name = None
            self.__balance_max = None
            self.__meta = None
            self.__reset_type = None
            self.__reset_day_of_month = None
            self.__reset_day_of_week = None
            self.__reset_hour = None
            self.__latest_gain_max = None
        else:
            self.set_gold_name(params['goldName'] if 'goldName' in params.keys() else None)
            self.set_balance_max(params['balanceMax'] if 'balanceMax' in params.keys() else None)
            self.set_meta(params['meta'] if 'meta' in params.keys() else None)
            self.set_reset_type(params['resetType'] if 'resetType' in params.keys() else None)
            self.set_reset_day_of_month(params['resetDayOfMonth'] if 'resetDayOfMonth' in params.keys() else None)
            self.set_reset_day_of_week(params['resetDayOfWeek'] if 'resetDayOfWeek' in params.keys() else None)
            self.set_reset_hour(params['resetHour'] if 'resetHour' in params.keys() else None)
            self.set_latest_gain_max(params['latestGainMax'] if 'latestGainMax' in params.keys() else None)

    def get_gold_name(self):
        """
        ゴールド名を取得
        :return: ゴールド名
        :rtype: unicode
        """
        return self.__gold_name

    def set_gold_name(self, gold_name):
        """
        ゴールド名を設定
        :param gold_name: ゴールド名
        :type gold_name: unicode
        """
        self.__gold_name = gold_name

    def get_balance_max(self):
        """
        各ウォレットの残高の最大値を取得
        :return: 各ウォレットの残高の最大値
        :rtype: long
        """
        return self.__balance_max

    def set_balance_max(self, balance_max):
        """
        各ウォレットの残高の最大値を設定
        :param balance_max: 各ウォレットの残高の最大値
        :type balance_max: long
        """
        self.__balance_max = balance_max

    def get_meta(self):
        """
        メタデータを取得
        :return: メタデータ
        :rtype: unicode
        """
        return self.__meta

    def set_meta(self, meta):
        """
        メタデータを設定
        :param meta: メタデータ
        :type meta: unicode
        """
        self.__meta = meta

    def get_reset_type(self):
        """
        取得量の期間制限のタイプを取得
        :return: 取得量の期間制限のタイプ
        :rtype: unicode
        """
        return self.__reset_type

    def set_reset_type(self, reset_type):
        """
        取得量の期間制限のタイプを設定
        :param reset_type: 取得量の期間制限のタイプ
        :type reset_type: unicode
        """
        self.__reset_type = reset_type

    def get_reset_day_of_month(self):
        """
        期間内の取得量をリセットする日にちを取得
        :return: 期間内の取得量をリセットする日にち
        :rtype: int
        """
        return self.__reset_day_of_month

    def set_reset_day_of_month(self, reset_day_of_month):
        """
        期間内の取得量をリセットする日にちを設定
        :param reset_day_of_month: 期間内の取得量をリセットする日にち
        :type reset_day_of_month: int
        """
        self.__reset_day_of_month = reset_day_of_month

    def get_reset_day_of_week(self):
        """
        期間内の取得量をリセットする曜日を取得
        :return: 期間内の取得量をリセットする曜日
        :rtype: unicode
        """
        return self.__reset_day_of_week

    def set_reset_day_of_week(self, reset_day_of_week):
        """
        期間内の取得量をリセットする曜日を設定
        :param reset_day_of_week: 期間内の取得量をリセットする曜日
        :type reset_day_of_week: unicode
        """
        self.__reset_day_of_week = reset_day_of_week

    def get_reset_hour(self):
        """
        期間内の取得量をリセットする時を取得
        :return: 期間内の取得量をリセットする時
        :rtype: int
        """
        return self.__reset_hour

    def set_reset_hour(self, reset_hour):
        """
        期間内の取得量をリセットする時を設定
        :param reset_hour: 期間内の取得量をリセットする時
        :type reset_hour: int
        """
        self.__reset_hour = reset_hour

    def get_latest_gain_max(self):
        """
        期間内の最大取得量を取得
        :return: 期間内の最大取得量
        :rtype: long
        """
        return self.__latest_gain_max

    def set_latest_gain_max(self, latest_gain_max):
        """
        期間内の最大取得量を設定
        :param latest_gain_max: 期間内の最大取得量
        :type latest_gain_max: long
        """
        self.__latest_gain_max = latest_gain_max

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return super(WalletSettings, self).__getitem__(key)

    def to_dict(self):
        return {
            "goldName": self.__gold_name,
            "balanceMax": self.__balance_max,
            "meta": self.__meta,
            "resetType": self.__reset_type,
            "resetDayOfMonth": self.__reset_day_of_month,
            "resetDayOfWeek": self.__reset_day_of_week,
            "resetHour": self.__reset_hour,
            "latestGainMax": self.__latest_gain_max,
        }
